package com.qmth.distributed.print.common.contant;

import com.qmth.boot.core.uid.service.UidService;

import java.io.File;
import java.nio.charset.Charset;
import java.util.Objects;
import java.util.StringJoiner;
import java.util.UUID;

/**
 * @Description: 系统常量
 * @Param:
 * @return:
 * @Author: wangliang
 * @Date: 2019/10/11
 */
public class SystemConstant {

    /**
     * 系统常量
     */
    public static final String CHARSET_NAME = "UTF-8";
    public static final Charset CHARSET = Charset.forName(CHARSET_NAME);
    public static final String MD5 = "MD5";
    public static final String SUCCESS = "success";
    public static final String EXTEND_COLUMN = "extendColumn";
    public static final String METHOD = "post";
    public static final String USER_DIR = "user.dir";
    public static final String PDF_TEMP = "pdf-temp";
    public static final String FILE_TEMP = "file-temp";

    /**
     * 鉴权
     */
    public static final String HEADER_AUTHORIZATION = "Authorization";
    public static final String HEADER_TIME = "time";
    public static final String HEADER_PLATFORM = "platform";
    public static final String HEADER_DEVICE_ID = "deviceId";
    public static final String TOKEN = "token";

    /**
     * redis
     */
    public static final long REDIS_DEFAULT_EXPIRE_TIME = 24 * 60L * 60L;//过期时间24小时

    /**
     * aes相关
     */
    public static final String AES = "AES";
    public static final String AES_MODE_PKCS5 = "AES/CBC/PKCS5Padding";//用这个模式，规则必须为16位
    public static final String AES_MODE_PKCS7 = "AES/CBC/PKCS7Padding";//用这个模式，规则必须为16位
    public static final String AES_RULE = "1234567890123456";//aes密钥


    /**
     * 变量
     */
    public static String TEMP_FILES_DIR;
    public static String PDF_TEMP_FILES_DIR;

    /**
     * 初始化附件文件路径
     */
    public static void initTempFiles() {
        StringJoiner localPath = new StringJoiner("").add(System.getProperty(USER_DIR));
        String mkdir = localPath.toString().substring(0, localPath.toString().lastIndexOf(File.separator));
        File fileTempDir = new File(new StringBuffer(mkdir).append(File.separator).append(FILE_TEMP).toString());
        if (!fileTempDir.exists()) {
            fileTempDir.mkdirs();
        }
        File pdfTempDir = new File(new StringBuffer(mkdir).append(File.separator).append(PDF_TEMP).toString());
        if (!pdfTempDir.exists()) {
            pdfTempDir.mkdirs();
        }
        TEMP_FILES_DIR = fileTempDir.getPath();
        PDF_TEMP_FILES_DIR = pdfTempDir.getPath();
    }

    /**
     * id转换为long
     *
     * @return
     */
    public static Long convertIdToLong(String id) {
        return Objects.nonNull(id) && id.length() > 0 ? Long.parseLong(id) : null;
    }

    /**
     * 获取全局uuid
     *
     * @return
     */
    public static String getUuid() {
        return String.valueOf(UUID.randomUUID()).replaceAll("-", "");
    }

    /**
     * 获取数据库uuid
     *
     * @return
     */
    public static Long getDbUuid() {
        UidService uidservice = SpringContextHolder.getBean(UidService.class);
        return uidservice.getId();
    }

    /**
     * enable转换
     *
     * @return
     */
    public static Boolean convertEnable(Boolean enable) {
        return Objects.nonNull(enable) ? enable : true;
    }
}