package com.qmth.distributed.print.api;


import com.baomidou.mybatisplus.core.metadata.IPage;
import com.qmth.boot.api.annotation.Aac;
import com.qmth.boot.api.annotation.BOOL;
import com.qmth.boot.api.constant.ApiConstant;
import com.qmth.distributed.print.business.bean.ApiUser;
import com.qmth.distributed.print.business.bean.dto.TemplateDto;
import com.qmth.distributed.print.business.entity.BasicTemplate;
import com.qmth.distributed.print.business.service.BasicTemplateService;
import com.qmth.distributed.print.business.util.RequestUtils;
import com.qmth.distributed.print.common.util.Result;
import com.qmth.distributed.print.common.util.ResultUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;

/**
 * <p>
 * 通用模板 前端控制器
 * </p>
 *
 * @author xf
 * @since 2021-03-23
 */
@Api(tags = "通用模板Controller")
@RestController
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + "/${prefix.url.basic}/template")
@Aac(auth = BOOL.FALSE)
public class BasicTemplateController {

    @Autowired
    private BasicTemplateService basicTemplateService;

    /**
     * 查询
     *
     * @param request
     * @param enable
     * @param type
     * @param name
     * @param startTime
     * @param endTime
     * @param pageNumber
     * @param pageSize
     * @return
     */
    @ApiOperation(value = "查询")
    @RequestMapping(value = "/list", method = RequestMethod.POST)
    public Result list(HttpServletRequest request,
                       @RequestParam Boolean enable,
                       @RequestParam String type,
                       @RequestParam String name,
                       @RequestParam Long startTime,
                       @RequestParam Long endTime,
                       @RequestParam Integer pageNumber,
                       @RequestParam Integer pageSize) {
        ApiUser apiUser = RequestUtils.getApiUser(request);
        IPage<TemplateDto> templateDtoIPage = basicTemplateService.list(apiUser.getSchoolId(), enable, type, name, startTime, endTime, pageNumber, pageSize);
        return ResultUtil.ok(templateDtoIPage);
    }

    /**
     * 新增/修改
     *
     * @param request
     * @param template
     * @return
     */
    @ApiOperation(value = "新增/修改")
    @RequestMapping(value = "/save", method = RequestMethod.POST)
    public Result save(HttpServletRequest request, @RequestBody BasicTemplate template) {
        ApiUser apiUser = RequestUtils.getApiUser(request);
        template.setSchoolId(apiUser.getSchoolId());
        template.setCreateId(template.getId() == null ? apiUser.getUserData().getId() : null);
        template.setUpdateId(template.getId() != null ? apiUser.getUserData().getId() : null);
        boolean isSuccess = basicTemplateService.saveTemplate(template);
        return ResultUtil.ok(isSuccess);
    }

    /**
     * 启用/禁用
     *
     * @param template
     * @return
     */
    @ApiOperation(value = "启用/禁用")
    @RequestMapping(value = "/enable", method = RequestMethod.POST)
    public Result enable(@RequestBody BasicTemplate template) {
        boolean isSuccess = basicTemplateService.enable(template);
        return ResultUtil.ok(isSuccess);
    }
}

